Learn R Programming

dexter (version 1.7.2)

coef.latent_cor: latent correlations

Description

latent correlations

Usage

# S3 method for latent_cor
coef(object, hpd = 0.95, ...)

Value

list with matrices cor, sd, hpd_l (lower boundary), hpd_u (upper boundary), array mcmc with the complete mcmc sample

Extract correlations with a specified highest posterior density interval

Arguments

object

resulting value from latent_cor

hpd

width of the confidence envelope of the Bayesian highest posterior density interval around the correlations, value must be between 0 and 1.

...

ignored