dexter-package: Dexter: data analyses for educational and psychological...

dexter-packageR Documentation

Dexter: data analyses for educational and psychological tests.

Description

Dexter provides a comprehensive solution for managing and analyzing educational test data.

Details

The main features are:

  • project databases providing a structure for storing data about persons, items, responses and booklets.

  • methods to assess data quality using Classical test theory and plots.

  • CML calibration of the extended nominal response model and interaction model.

To learn more about dexter, start with the vignettes: 'browseVignettes(package="dexter")'

Dexter uses the following global options

  • dexter.use_tibble return tibbles instead of data.frames, defaults to FALSE

  • dexter.verbose if FALSE, turn off all informative messages, defaults to TRUE

  • dexter.progress show progress bars, defaults to TRUE in interactive sessions

  • dexter.max_cores set a maximum number of cores that dexter will use, defaults to the minimum of Sys.getenv("OMP_THREAD_LIMIT") and getOption("Ncpus"), otherwise unlimited.

Author(s)

Maintainer: Jesse Koops jesse.koops@cito.nl

Authors:

See Also

Useful links:


dexter documentation built on July 24, 2026, 5:06 p.m.