| dexter-package | R Documentation |
Dexter provides a comprehensive solution for managing and analyzing educational test data.
The main features are:
project databases providing a structure for storing data about persons, items, responses and booklets.
methods to assess data quality using Classical test theory and plots.
CML calibration of the extended nominal response model and interaction model.
To learn more about dexter, start with the vignettes: 'browseVignettes(package="dexter")'
Dexter uses the following global options
dexter.use_tibble return tibbles instead of data.frames, defaults to FALSE
dexter.verbose if FALSE, turn off all informative messages, defaults to TRUE
dexter.progress show progress bars, defaults to TRUE in interactive sessions
dexter.max_cores set a maximum number of cores that dexter will use, defaults to the minimum of Sys.getenv("OMP_THREAD_LIMIT") and
getOption("Ncpus"), otherwise unlimited.
Maintainer: Jesse Koops jesse.koops@cito.nl
Authors:
Jesse Koops jesse.koops@cito.nl
Gunter Maris
Timo Bechger
Ivailo Partchev
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.